// modelling migration and urbanisation using directly estimated migration rates for asia and africa //

**define working directory (cd)

//////////////////////////////////////////////////////////////////////////////////////

// combine files of 1-, 2.5- and 5-year migration rates for Africa and Asia

*2.5 year rates
use "Africa\Census-UR-In_3.dta", clear
append using "Asia\Census-UR-In_3.dta"
gen inflow = 1
append using "Africa\Census-UR-Out_3.dta"
append using "Asia\Census-UR-Out_3.dta"
replace inflow= 0 if inflow==.
gen period = 3
*adding 5 year rates
append using "Africa\Census-UR-In_5.dta"
append using "Asia\Census-UR-In_5.dta"
replace inflow= 1 if inflow==.
append using "Africa\Census-UR-Out_5.dta"
append using "Asia\Census-UR-Out_5.dta"
replace inflow= 0 if inflow==.
replace period=5 if period==.
*adding 1 year rates (africa only)
append using "Africa\Census-UR-In_1.dta"
replace inflow= 1 if inflow==.
append using "Africa\Census-UR-Out_1.dta"
replace inflow= 0 if inflow==.
replace period=1 if period==.

save UR_all.dta


///////////////////////////////////////////////////////////////////////////////////////

// preparing the file

use UR_all.dta,clear

**note: rwanda is missing education (only "100" category)
**note: nepal and rwanda only have rural regions so removed
drop if country=="RW" | country=="NP"

*variable determining regions 
gen region="Africa" if (country=="BF" |country=="BJ" | country=="BW" | country=="CM" | country=="EG" | country=="GH" | country=="GN" | country=="KE" |country=="ML" | country=="MU" |country=="MW" | country=="MZ" | country=="SD" | country=="SN" |country=="TG" | country=="TZ" |country=="UG" | country=="ZA" |country=="ZM" )
replace region="Asia" if region=="" & (country=="CN" |country=="ID" | country=="IQ" | country=="KG" | country=="MN" | country=="MY" | country=="PH" | country=="TH" | country=="VT")


* merge data according to country and year, with external proportions urban (PU) available from World Urbanisation Prospects 
merge m:1 country year using "WUP_PU.dta"
keep if _merge==3
drop _merge

*recoding some variables
encode region, gen(africa)
recode africa (2=0)

encode country, gen(Country) label(c)

egen census= concat(country year)

gen agegp= cond(age2<8,(age2-1)*5,(age2-4)*5)  if age2<100 
replace agegp=100 if age2==100 

recode year (1970/1979=1 "1970s") (1980/1989=2 "1980s") (1990/1999=3 "1990s") (2000/2009=4 "2000s") (2010/2019=5 "2010s"), gen(decade)

gen migflow=1 	if orig=="urban"		& dest=="urban"
			replace migflow=2 if orig=="urban"		& dest=="rural"
			replace migflow=3 if orig=="rural"		& dest=="urban"
			replace migflow=4 if orig=="rural"		& dest=="rural"
			replace migflow=5 if orig=="capital"	& dest=="capital"
			replace migflow=6 if orig=="capital"	& dest=="otherurban"
			replace migflow=7 if orig=="capital"	& dest=="rural"
			replace migflow=8 if orig=="otherurban"	& dest=="capital"
			replace migflow=9 if orig=="otherurban"	& dest=="otherurban"
			replace migflow=10 if orig=="otherurban"	& dest=="rural"
			replace migflow=11 if orig=="rural"		& dest=="capital"
			replace migflow=12 if orig=="rural"		& dest=="otherurban"
			replace migflow=13 if orig=="rural"		& dest=="rural"
				
lab def labelmigflow ///
				1 "urban-urban" ///
				2 "urban-rural" ///
				3 "rural-urban" ///
				4 "rural-rural" ///
				5 "capital-capital" ///
				6 "capital-otherurban" ///
				7 "capital-rural" ///
				8 "otherurban-capital" ///
				9 "otherurban-otherurban" ///
				10 "otherurban-rural" ///
				11 "rural-capital" ///
				12 "rural-otherurban" ///
				13 "rural-rural" , modify
lab val migflow labelmigflow

*interested only on between sector flows
keep if orig!=dest

* BEFORE MODEL
* WARNING: to make right interpretation of net-migration
* Migration rates will be interpretable the other way round (origin<=>destination) 
recode migflow (2=3) (3=2) if inflow==1

* in order to account for the different periods the rates cover, we first recompute the migration rates to all be as if period 1 - annual rates
/*
poisson migrations ///
		ib1.period ///
		if sex!=100 & educ!=100 & agegp!=100 , ///
		exposure(PYAR) irr iter(30)
****				
Poisson regression                                    Number of obs =   24,824
                                                      LR chi2(2)    = 1.70e+07
                                                      Prob > chi2   =   0.0000
Log likelihood = -1.103e+08                           Pseudo R2     =   0.0717

------------------------------------------------------------------------------
  migrations |        IRR   Std. err.      z    P>|z|     [95% conf. interval]
-------------+----------------------------------------------------------------
      period |
          3  |   .3940313   .0001831 -2004.23   0.000     .3936726    .3943903
          5  |   .1899535   .0000838 -3763.79   0.000     .1897893    .1901179
             |
       _cons |    .010485   4.44e-06 -1.1e+04   0.000     .0104763    .0104937
    ln(PYAR) |          1  (exposure)
------------------------------------------------------------------------------
		
*/
*we note that the 1yr rates are 5 times the 5 year, and that the 2.5yr(3) rates are half of the 5yr, and we adjust to all be 1 year (annual rates)
gen migrations_all1 = migrations
replace migrations_all1= migrations/.3940313 if period==3
replace migrations_all1= migrations/.1899535 if period==5


* compute indicator variable for under-5, to control for underestimation bias (only possible when we have 1 yr estimates)
capture drop under5
gen under5=0
replace under5= 1 if agegp==0 & period==3
replace under5= 2 if agegp==0 & period==5

* population weights- inverse of country size
bys country year dest: gen total_pop=sum(PYAR) if edu==100 & sex==100 & age2==100 & inflow==1
bys country year: gen pop=sum(total_pop)
bys country year: egen national_pop= max(pop) 
gen country_pop = national_pop /period 
gen weight= 1/ country_pop
drop total_pop pop national_pop


*census with only capital and no other urban
gen no_otherurb=0
replace no_otherurb =1 if census=="BF1996" | census=="ID1980" | census=="ID1985" | census=="ID1990" | census=="KE1979" | census=="KE1989" | census=="KE1999" | census=="KE2009" | census=="KG1999" | census=="ML1998" | census=="NP2001" | census=="NP2011" | census=="RW1991" | census=="RW2002" | census=="SD2008" | census=="SN2002" | census=="TG2010" | census=="TH1970" |  census=="TH1990" |   census=="TH2000" |   census=="UG1991" |   census=="UG2002" |   census=="VT1989" |   census=="VT1999" 

 
save "UR_clean_annual", replace

///////////////////////////////////////////////////////////////////////////////////

// modeling of migration

use "UR_clean_annual", clear


****africa
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		ib0.under5 ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100  & region=="Africa" , ///
		exposure(PYAR) irr iter(40)
		
****asia
*note: for asia we do analysis without under-5s since we do not have estimates of period 1

poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0 & region=="Asia" , ///
		exposure(PYAR) irr iter(40)
		

**** margins for asia/ africa - used after models
*in-migration age-sex pattern UR	(for out-migration change inflow to 0)
margins migflow ,at(agegp=0 sex==(1(1)2) inflow=1  under5==0) ///
				 at(agegp=5 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=10 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=15 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=20 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=25 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=30 sex==(1(1)2) inflow=1 )  /// 
				 at(agegp=35 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=40 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=45 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=50 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=55 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=60 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=65 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=70 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=75 sex==(1(1)2) inflow=1 ) ///
				 at(agegp=80 sex==(1(1)2) inflow=1 ) ///
						 	 			predict(ir) atmeans
marginsplot, xdim(at(agegp)) xlabels(0(10)80)  ///
			by(migflow) byopts(colfirst) recast(line) recastci(rarea) ciopts(fintensity(inten20)) ///
			yline(0)
						
*net over time
margins migflow , at(decade==(1(1)5)) dydx(inflow) predict(ir) atmeans
marginsplot, xdim(at(decade)) by(migflow)  byopts(colfirst) recast(line) recastci(rarea) ciopts(fintensity(inten20) yline(0, lcol(gs8))) 

*net over PU
margins migflow , at(PU==(10(10)60) ) dydx(inflow) predict(ir) atmeans
marginsplot, xdim(at(PU)) by(migflow)  byopts(colfirst) recast(line) recastci(rarea) ciopts(fintensity(inten20) yline(0, lcol(gs8))) 

*in-migration over PU
margins migflow , at(PU==(10(10)60) inflow=1) predict(ir) atmeans
marginsplot, xdim(at(PU)) by(migflow)  byopts(colfirst) recast(line) recastci(rarea) ciopts(fintensity(inten20) yline(0, lcol(gs8))) 

*out-migration over PU
margins migflow , at(PU==(10(10)60) inflow=0) predict(ir) atmeans
marginsplot, xdim(at(PU)) by(migflow)  byopts(colfirst) recast(line) recastci(rarea) ciopts(fintensity(inten20) yline(0, lcol(gs8))) 


*****************************************************************************
*** robustness tests ****

//excluding census with only capital / without

poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		ib0.under5 ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 &  region=="Africa" & no_otherurb!=1, ///
		exposure(PYAR) irr iter(40)

		
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0  & region=="Asia" & no_otherurb!=1, ///
		exposure(PYAR) irr iter(40)
		
		
//drop 1-year estimates from Africa

poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0 & region=="Africa" & period!=1 , ///
		exposure(PYAR) irr iter(40)


// decade interaction

poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
		ib2.migflow#ib0.inflow#ib1.decade ///
 		ib0.under5 ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & region=="Africa" , ///
		exposure(PYAR) irr iter(40)
		
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
		ib2.migflow#ib0.inflow#ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0 & region=="Asia" , ///
		exposure(PYAR) irr iter(40)
		

// excluding specific countries 
* China
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0 & region=="Asia" & country!="CN", ///
		exposure(PYAR) irr iter(40)
		
* outlying Asian countries in terms of PU when compared to WUPS 300k
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & agegp!=0 & region=="Asia" & country!="IQ" & census!="MY2000", ///
		exposure(PYAR) irr iter(40)
		
*South africa
poisson migrations_all1 ///
		ib2.sex#ib20.agegp#ib2.migflow#ib0.inflow   ///
		ib2.migflow#ib0.inflow#c.PU ///
		ib2.migflow#ib0.inflow#c.PU#c.PU   ///
 		ib1.decade ///
		ib0.under5 ///
		[pw=weight] ///
		if sex!=100 & educ==100 & agegp!=100 & region=="Africa" & country!="ZA", ///
		exposure(PYAR) irr iter(40)
			
	
